@@ -9,7 +9,7 @@ use base qw( Log::Dispatch::Base );
 
 use Carp ();
 
-$VERSION = '2.11';
+$VERSION = '2.18';
 
 1;
 
@@ -65,6 +65,11 @@ sub log
     my $self = shift;
     my %p = @_;
 
+    return unless $self->would_log( $p{level} );
+
+    $p{message} = $p{message}->()
+        if ref $p{message} eq 'CODE';
+
     $p{message} = $self->_apply_callbacks(%p)
 	if $self->{callbacks};
 
@@ -206,12 +211,21 @@ Removes the object that matches the name given to the remove method.
 The return value is the object being removed or undef if no object
 matched this.
 
-=item * log( level => $, message => $ )
+=item * log( level => $, message => $ or \& )
 
 Sends the message (at the appropriate level) to all the
 Log::Dispatch::* objects that the dispatcher contains (by calling the
 C<log_to> method repeatedly).
 
+This method also accepts a subroutine reference as the message
+argument. This reference will be called only if there is an output
+that will accept a message of the specified level.
+
+B<WARNING>: This is the only logging method that does something
+intelligent with a subroutine reference as the message. Other methods,
+like C<log_to()> or the C<log()> method of an output object, will just
+stringify the reference.
+
 =item * log_to( name => $, level => $, message => $ )
 
 Sends the message only to the named object.
@@ -388,19 +402,29 @@ Simpler than Log::Log4perl.
 A very different API for doing many of the same things that
 Log::Dispatch does.  Originally written by Raphael Manfredi.
 
+=head1 SUPPORT
+
+Please submit bugs and patches to the CPAN RT system at
+http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Log%3A%3ADispatch
+or via email at bug-log-dispatch@rt.cpan.org.
+
+Support questions can be sent to me at my email address, shown below.
+
+The code repository is at https://svn.urth.org/svn/Log-Dispatch/
+
+=head1 AUTHOR
+
+Dave Rolsky, <autarch@urth.org>
+
 =head1 COPYRIGHT
 
-Copyright (c) 1999-2003 David Rolsky.  All rights reserved.  This
+Copyright (c) 1999-2006 David Rolsky.  All rights reserved.  This
 program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 The full text of the license can be found in the LICENSE file included
 with this module.
 
-=head1 AUTHOR
-
-Dave Rolsky, <autarch@urth.org>
-
 =head1 SEE ALSO
 
 Log::Dispatch::ApacheLog, Log::Dispatch::Email,
